@@ -1,11 +1,6 @@
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-version_info = (
-    4,
-    0,
-    1,
-    #'dev'
-)
+version_info = (4, 0, 4)
 
 __version__ = '.'.join(map(str, version_info))
